@@ -1,8 +1,8 @@
 /* tifffastcrop
 
- v. 1.3.8
+ v. 1.3.10
 
- Copyright (c) 2013-2016 Christophe Deroulers
+ Copyright (c) 2013-2017 Christophe Deroulers
 
  Portions are based on libtiff's tiffcp code. tiffcp is:
  Copyright (c) 1988-1997 Sam Leffler
@@ -43,11 +43,11 @@
 #define EXIT_GEOMETRY_ERROR	6
 
 #define CopyField(tag, v) \
-    if (TIFFGetField(in, tag, &v)) TIFFSetField(out, tag, v)
+    if (TIFFGetField(in, tag, &v)) TIFFSetField(TIFFout, tag, v)
 #define CopyField2(tag, v1, v2) \
-    if (TIFFGetField(in, tag, &v1, &v2)) TIFFSetField(out, tag, v1, v2)
+    if (TIFFGetField(in, tag, &v1, &v2)) TIFFSetField(TIFFout, tag, v1, v2)
 #define CopyField3(tag, v1, v2, v3) \
-    if (TIFFGetField(in, tag, &v1, &v2, &v3)) TIFFSetField(out, tag, v1, v2, v3)
+    if (TIFFGetField(in, tag, &v1, &v2, &v3)) TIFFSetField(TIFFout, tag, v1, v2, v3)
 
 static uint32 requestedxmin = 0;
 static uint32 requestedymin = 0;
@@ -161,7 +161,7 @@ static const char * searchSuffix(const char * path)
 }
 
 
-static void tiffCopyFieldsButDimensions(TIFF* in, TIFF* out)
+static void tiffCopyFieldsButDimensions(TIFF* in, TIFF* TIFFout)
 {
 	uint16 bitspersample, samplesperpixel, compression, shortv, *shortav;
 	float floatv;
@@ -181,8 +181,8 @@ static void tiffCopyFieldsButDimensions(TIFF* in, TIFF* out)
 	CopyField(TIFFTAG_MAXSAMPLEVALUE, shortv);
 	CopyField(TIFFTAG_XRESOLUTION, floatv);
 	CopyField(TIFFTAG_YRESOLUTION, floatv);
-	CopyField(TIFFTAG_GROUP3OPTIONS, longv);
-	CopyField(TIFFTAG_GROUP4OPTIONS, longv);
+/*	CopyField(TIFFTAG_GROUP3OPTIONS, longv);
+	CopyField(TIFFTAG_GROUP4OPTIONS, longv);*/
 	CopyField(TIFFTAG_RESOLUTIONUNIT, shortv);
 	CopyField(TIFFTAG_PLANARCONFIG, shortv);
 	CopyField(TIFFTAG_XPOSITION, floatv);
@@ -206,12 +206,6 @@ static void tiffCopyFieldsButDimensions(TIFF* in, TIFF* out)
 	CopyField(TIFFTAG_HOSTCOMPUTER, stringv);
 	CopyField(TIFFTAG_PAGENAME, stringv);
 	CopyField(TIFFTAG_DOCUMENTNAME, stringv);
-	CopyField(TIFFTAG_BADFAXLINES, longv);
-	CopyField(TIFFTAG_CLEANFAXDATA, longv);
-	CopyField(TIFFTAG_CONSECUTIVEBADFAXLINES, longv);
-	CopyField(TIFFTAG_FAXRECVPARAMS, longv);
-	CopyField(TIFFTAG_FAXRECVTIME, longv);
-	CopyField(TIFFTAG_FAXSUBADDRESS, stringv);
 	CopyField(TIFFTAG_FAXDCS, stringv);
 }
 
@@ -387,7 +381,7 @@ static int testAndFixInTIFFPhotoAndCompressionParameters(TIFF* in,
 {
 	uint16 bitspersample, input_photometric;
 
-	TIFFGetField(in, TIFFTAG_BITSPERSAMPLE, &bitspersample);
+	TIFFGetFieldDefaulted(in, TIFFTAG_BITSPERSAMPLE, &bitspersample);
 
 	TIFFGetFieldDefaulted(in, TIFFTAG_COMPRESSION, input_compression);
 	TIFFGetFieldDefaulted(in, TIFFTAG_PHOTOMETRIC, &input_photometric);
@@ -426,7 +420,7 @@ static int testAndFixOutTIFFPhotoAndCompressionParameters(TIFF* in,
 {
 	uint16 input_photometric, input_compression, compression, spp;
 
-	TIFFGetField(in, TIFFTAG_SAMPLESPERPIXEL, &spp);
+	TIFFGetFieldDefaulted(in, TIFFTAG_SAMPLESPERPIXEL, &spp);
 	TIFFGetFieldDefaulted(in, TIFFTAG_COMPRESSION, &input_compression);
 	TIFFGetFieldDefaulted(in, TIFFTAG_PHOTOMETRIC, &input_photometric);
 
@@ -476,6 +470,22 @@ static int testAndFixOutTIFFPhotoAndCompressionParameters(TIFF* in,
 		    input_photometric == PHOTOMETRIC_YCBCR)
 			TIFFSetField(TIFFout, TIFFTAG_PHOTOMETRIC,
 				PHOTOMETRIC_RGB);
+	} else if (compression == COMPRESSION_CCITTFAX3 ||
+		   compression == COMPRESSION_CCITTFAX4) {
+		uint32 longv;
+		char *stringv;
+		if (compression == COMPRESSION_CCITTFAX3 &&
+		    input_compression == COMPRESSION_CCITTFAX3)
+			{ CopyField(TIFFTAG_GROUP3OPTIONS, longv); }
+		else if (compression == COMPRESSION_CCITTFAX4 &&
+		    input_compression == COMPRESSION_CCITTFAX4)
+			CopyField(TIFFTAG_GROUP4OPTIONS, longv);
+		CopyField(TIFFTAG_BADFAXLINES, longv);
+		CopyField(TIFFTAG_CLEANFAXDATA, longv);
+		CopyField(TIFFTAG_CONSECUTIVEBADFAXLINES, longv);
+		CopyField(TIFFTAG_FAXRECVPARAMS, longv);
+		CopyField(TIFFTAG_FAXRECVTIME, longv);
+		CopyField(TIFFTAG_FAXSUBADDRESS, stringv);
 	}
 
 	/*if (defphotometric != (uint16) -1)
@@ -603,7 +613,7 @@ static int cpStrips2Strip(TIFF* in,
 	}
 
 	/* When compression method doesn't support random access: */
-	if (input_compression == COMPRESSION_JPEG) {
+	if (input_compression != COMPRESSION_NONE) {
 		uint32 y;
 
 		if (*y_of_last_read_scanline > ymin) {
@@ -714,8 +724,8 @@ static int makeExtractFromTIFFFile(const char * infilename,
 
 	TIFFGetField(in, TIFFTAG_IMAGEWIDTH, &inimagewidth);
 	TIFFGetField(in, TIFFTAG_IMAGELENGTH, &inimagelength);
-	TIFFGetField(in, TIFFTAG_SAMPLESPERPIXEL, &spp);
-	TIFFGetField(in, TIFFTAG_BITSPERSAMPLE, &bitspersample);
+	TIFFGetFieldDefaulted(in, TIFFTAG_SAMPLESPERPIXEL, &spp);
+	TIFFGetFieldDefaulted(in, TIFFTAG_BITSPERSAMPLE, &bitspersample);
 
 	if (output_format == OUTPUT_FORMAT_JPEG &&
 	    (bitspersample != 8 || spp != 3)) {
@@ -1109,7 +1119,7 @@ static int makeExtractFromTIFFFile(const char * infilename,
 
 static void usage()
 {
-	fprintf(stderr, "tifffastcrop v" PACKAGE_VERSION " license GNU GPL v3 (c) 2013-2016 Christophe Deroulers\n\n");
+	fprintf(stderr, "tifffastcrop v" PACKAGE_VERSION " license GNU GPL v3 (c) 2013-2017 Christophe Deroulers\n\n");
 	fprintf(stderr, "Quote \"Deroulers et al., Diagnostic Pathology 2013, 8:92\" in your production\n       http://doi.org/10.1186/1746-1596-8-92\n\n");
 	fprintf(stderr, "Usage: tifffastcrop [options] input.tif [output_name]\n\n");
 	fprintf(stderr, " Extracts (crops), without loading the full image input.tif into memory, a\nrectangular region from it, and saves it. Output file name is output_name if\ngiven, otherwise a name derived from input.tif. Output file format is guessed\nfrom output_name's extension if possible. Options:\n");
