@@ -1,8 +1,8 @@
 /* tiffmakemosaic
 
- v. 1.3.8
+ v. 1.3.10
 
- Copyright (c) 2012-2016 Christophe Deroulers
+ Copyright (c) 2012-2017 Christophe Deroulers
 
  Portions are based on libtiff's tiffcp code. tiffcp is
  Copyright (c) 1988-1997 Sam Leffler
@@ -216,8 +216,8 @@ static int testAndFixParameters(TIFF* in,
 	uint16 spp, bitspersample;
 	uint16 input_photometric, compression;
 
-	TIFFGetField(in, TIFFTAG_SAMPLESPERPIXEL, &spp);
-	TIFFGetField(in, TIFFTAG_BITSPERSAMPLE, &bitspersample);
+	TIFFGetFieldDefaulted(in, TIFFTAG_SAMPLESPERPIXEL, &spp);
+	TIFFGetFieldDefaulted(in, TIFFTAG_BITSPERSAMPLE, &bitspersample);
 	if (output_to_jpeg_rather_than_tiff) {
 		assert( bitspersample == 8 );
 		assert( spp == 3 );
@@ -502,7 +502,7 @@ cpStrips2Strip(TIFF* in, void * ambiguous_out,
 	}
 
 	/* When compression method doesn't support random access: */
-	if (input_compression == COMPRESSION_JPEG) {
+	if (input_compression != COMPRESSION_NONE) {
 		uint32 y;
 
 		if (*y_of_last_read_scanline > ymin) {
@@ -677,8 +677,8 @@ makeMosaicFromTIFFFile(char * infilename)
 
 	TIFFGetField(in, TIFFTAG_IMAGEWIDTH, &inimagewidth);
 	TIFFGetField(in, TIFFTAG_IMAGELENGTH, &inimagelength);
-	TIFFGetField(in, TIFFTAG_SAMPLESPERPIXEL, &spp);
-	TIFFGetField(in, TIFFTAG_BITSPERSAMPLE, &bitspersample);
+	TIFFGetFieldDefaulted(in, TIFFTAG_SAMPLESPERPIXEL, &spp);
+	TIFFGetFieldDefaulted(in, TIFFTAG_BITSPERSAMPLE, &bitspersample);
 
 	if (output_JPEG_files && bitspersample != 8 && spp != 3) {
 		TIFFError(TIFFFileName(in),
@@ -1050,7 +1050,7 @@ makeMosaicFromTIFFFile(char * infilename)
 static void
 usage()
 {
-	fprintf(stderr, "tiffmakemosaic v" PACKAGE_VERSION " license GNU GPL v3 (c) 2012-2016 Christophe Deroulers\n\n");
+	fprintf(stderr, "tiffmakemosaic v" PACKAGE_VERSION " license GNU GPL v3 (c) 2012-2017 Christophe Deroulers\n\n");
 	fprintf(stderr, "Quote \"Deroulers et al., Diagnostic Pathology 2013, 8:92\" in your production\n       http://doi.org/10.1186/1746-1596-8-92\n\n");
 	fprintf(stderr, "Usage: tiffmakemosaic [options] file1.tif [file2.tif...]\n");
 	fprintf(stderr, " Produces a mosaic if needed, for each of the given files. A mosaic is a set of one-strip TIFF files of equal size, each of which has bounded size, which reproduce the original file if reassembled contiguously. Options:\n");
